@@ -1,4 +1,4 @@
-// Copyright 2024 The Khronos Group
+// Copyright 2024-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
@@ -27,7 +27,7 @@ struct Renderer : public Object
   static Renderer *createInstance(
       std::string_view subtype, HeCoreDeviceGlobalState *d);
 
-  void commit() override;
+  void commitParameters() override;
 
   float4 background() const;
 
