@@ -1,4 +1,4 @@
-// Copyright 2024 The Khronos Group
+// Copyright 2024-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #include "Surface.h"
@@ -7,7 +7,7 @@ namespace hecore {
 
 Surface::Surface(HeCoreDeviceGlobalState *s) : Object(ANARI_SURFACE, s) {}
 
-void Surface::commit()
+void Surface::commitParameters()
 {
   m_id = getParam<uint32_t>("id", ~0u);
   m_geometry = getParamObject<Geometry>("geometry");
