@@ -1,4 +1,4 @@
-// Copyright 2022-2024 The Khronos Group
+// Copyright 2021-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
@@ -18,8 +18,8 @@ struct Geometry : public Object
 
   RTCGeometry embreeGeometry() const;
 
-  void commit() override;
-  void markCommitted() override;
+  void commitParameters() override;
+  void markFinalized() override;
 
   virtual float4 getAttributeValue(const Attribute &attr, const Ray &ray) const;
   uint32_t getPrimID(const Ray &ray) const;
