@@ -1,8 +1,17 @@
-// Copyright 2024 The Khronos Group
+// Copyright 2024-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #include "points.h"
 
+#include "anariTokens.h"
+#include "geometry.h"
+
+// anari
+#include <anari/frontend/anari_enums.h>
+#include <anari/anari_cpp.hpp>
+#include <anari/anari_cpp/anari_cpp_impl.hpp>
+// pxr
+#include <pxr/base/gf/vec4f.h>
 #include <pxr/base/tf/diagnostic.h>
 #include <pxr/base/tf/staticData.h>
 #include <pxr/base/tf/token.h>
@@ -14,15 +23,11 @@
 #include <pxr/imaging/hd/sceneDelegate.h>
 #include <pxr/imaging/hd/tokens.h>
 #include <pxr/imaging/hd/types.h>
-#include <algorithm>
-#include <anari/anari_cpp.hpp>
-#include <iterator>
 // std
+#include <algorithm>
+#include <iterator>
 #include <string>
 
-#include "anariTokens.h"
-#include "geometry.h"
-
 using namespace std::string_literals;
 
 PXR_NAMESPACE_OPEN_SCOPE
@@ -47,14 +52,22 @@ HdDirtyBits HdAnariPoints::GetInitialDirtyBitsMask() const
   return mask;
 }
 
-HdAnariMaterial::PrimvarBinding HdAnariPoints::UpdateGeometry(
+HdAnariGeometry::GeomSpecificPrimvars HdAnariPoints::GetGeomSpecificPrimvars(
     HdSceneDelegate *sceneDelegate,
     HdDirtyBits *dirtyBits,
     const TfToken::Set &allPrimvars,
-    const VtValue &points)
+    const VtVec3fArray &points,
+    const SdfPath &geomsetId)
 {
-  // Sphere radii //
+  GeomSpecificPrimvars primvars;
+
+  // Sphere radii
   if (HdChangeTracker::IsDirty(HdChangeTracker::DirtyWidths)) {
+    if (m_radiiArray) {
+      anari::release(device_, m_radiiArray);
+      m_radiiArray = {};
+    }
+
     if (const auto &widthsVt = sceneDelegate->Get(GetId(), HdTokens->widths);
         widthsVt.IsHolding<VtFloatArray>()) {
       const auto &widths = widthsVt.UncheckedGet<VtFloatArray>();
@@ -64,25 +77,39 @@ HdAnariMaterial::PrimvarBinding HdAnariPoints::UpdateGeometry(
           std::cend(widths),
           std::back_inserter(radii),
           [](auto v) { return v / 2.0f; });
-      _SetGeometryAttributeArray(
-          HdAnariTokens->radius, HdAnariTokens->vertexRadius, VtValue(radii));
-    } else {
-      _SetGeometryAttributeArray(
-          HdAnariTokens->radius, HdAnariTokens->vertexRadius, VtValue());
+
+      m_radiiArray = _GetAttributeArray(VtValue(radii), ANARI_FLOAT32);
+      primvars.push_back({HdAnariTokens->vertexRadius, m_radiiArray});
     }
   }
-
-  return {};
+  return primvars;
 }
 
-void HdAnariPoints::UpdatePrimvarSource(HdSceneDelegate *sceneDelegate,
+HdAnariGeometry::PrimvarSource HdAnariPoints::UpdatePrimvarSource(
+    HdSceneDelegate *sceneDelegate,
     HdInterpolation interpolation,
     const TfToken &attributeName,
     const VtValue &value)
 {
   switch (interpolation) {
   case HdInterpolationConstant: {
-    _SetGeometryAttributeConstant(attributeName, value);
+    if (value.IsArrayValued()) {
+      if (value.GetArraySize() == 0) {
+        TF_RUNTIME_ERROR("Constant interpolation with no value.");
+        return {};
+      }
+      if (value.GetArraySize() > 1) {
+        TF_RUNTIME_ERROR("Constant interpolation with more than one value.");
+      }
+    }
+
+    GfVec4f v;
+    if (_GetVtValueAsAttribute(value, v)) {
+      return v;
+    } else {
+      TF_RUNTIME_ERROR(
+          "Error extracting value from primvar %s", attributeName.GetText());
+    }
     break;
   }
   case HdInterpolationUniform:
@@ -91,18 +118,20 @@ void HdAnariPoints::UpdatePrimvarSource(HdSceneDelegate *sceneDelegate,
   }
   case HdInterpolationVarying:
   case HdInterpolationVertex: {
-    auto bindingPoint = _GetVertexBindingPoint(attributeName);
-    if (bindingPoint.IsEmpty()) {
-      TF_CODING_ERROR("%s is not a valid vertex geometry attribute\n",
-          attributeName.GetText());
-      break;
-    }
-    _SetGeometryAttributeArray(attributeName, bindingPoint, value);
+    return _GetAttributeArray(value);
     break;
   }
   default:
     break;
   }
+  return {};
+}
+
+void HdAnariPoints::Finalize(HdRenderParam *renderParam)
+{
+  anari::release(device_, m_radiiArray);
+
+  HdAnariGeometry::Finalize(renderParam);
 }
 
 PXR_NAMESPACE_CLOSE_SCOPE
